#[non_exhaustive]pub struct CustomHostConfig {
pub html: String,
pub api: String,
pub git_ssh: String,
pub git_http: String,
/* private fields */
}Expand description
Custom host config for the instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.html: StringRequired. The custom UI hostname for the instance, e.g., “git.source.internal.mycompany.com”
api: StringRequired. The custom API hostname for the instance, e.g., “api.source.internal.mycompany.com”
git_ssh: StringRequired. The custom git ssh hostname for the instance, e.g., “ssh.source.internal.mycompany.com”
git_http: StringRequired. The custom git http hostname for the instance, e.g., “git.source.internal.mycompany.com”
Implementations