#[non_exhaustive]pub struct DeleteInstanceRequest {
pub name: String,
pub request_id: String,
pub force: bool,
/* private fields */
}Expand description
DeleteInstanceRequest is the request for deleting an instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Name of the resource.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
force: boolOptional. If set to true, will force the deletion of the instance.
Implementations
Sourceimpl DeleteInstanceRequest
impl DeleteInstanceRequest