#[non_exhaustive]pub struct Instance {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub private_config: Option<PrivateConfig>,
pub state: State,
pub state_note: StateNote,
pub kms_key: String,
pub host_config: Option<HostConfig>,
pub workforce_identity_federation_config: Option<WorkforceIdentityFederationConfig>,
/* private fields */
}Expand description
A resource that represents a Secure Source Manager instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. A unique identifier for an instance. The name should be of the
format:
projects/{project_number}/locations/{location_id}/instances/{instance_id}
project_number: Maps to a unique int64 id assigned to each project.
location_id: Refers to the region where the instance will be deployed.
Since Secure Source Manager is a regional service, it must be one of the
valid GCP regions.
instance_id: User provided name for the instance, must be unique for a
project_number and location_id combination.
create_time: Option<Timestamp>Output only. Create timestamp.
update_time: Option<Timestamp>Output only. Update timestamp.
labels: HashMap<String, String>Optional. Labels as key value pairs. Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. For more information, see Requirements for labels.
private_config: Option<PrivateConfig>Optional. Private settings for private instance.
state: StateOutput only. Current state of the instance.
state_note: StateNoteOutput only. An optional field providing information about the current instance state.
kms_key: StringOptional. Immutable. Customer-managed encryption key name, in the format projects//locations//keyRings//cryptoKeys/.
host_config: Option<HostConfig>Output only. A list of hostnames for this instance.
workforce_identity_federation_config: Option<WorkforceIdentityFederationConfig>Optional. Configuration for Workforce Identity Federation to support third party identity provider. If unset, defaults to the Google OIDC IdP.
Implementations
Sourceimpl Instance
impl Instance
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_private_config<T>(self, v: T) -> Selfwhere
T: Into<PrivateConfig>,
pub fn set_private_config<T>(self, v: T) -> Selfwhere
T: Into<PrivateConfig>,
Sets the value of private_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::PrivateConfig;
let x = Instance::new().set_private_config(PrivateConfig::default()/* use setters */);Sourcepub fn set_or_clear_private_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateConfig>,
pub fn set_or_clear_private_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateConfig>,
Sets or clears the value of private_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::PrivateConfig;
let x = Instance::new().set_or_clear_private_config(Some(PrivateConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_private_config(None::<PrivateConfig>);Sourcepub fn set_state_note<T: Into<StateNote>>(self, v: T) -> Self
pub fn set_state_note<T: Into<StateNote>>(self, v: T) -> Self
Sets the value of state_note.
Example
use google_cloud_securesourcemanager_v1::model::instance::StateNote;
let x0 = Instance::new().set_state_note(StateNote::PausedCmekUnavailable);Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_host_config<T>(self, v: T) -> Selfwhere
T: Into<HostConfig>,
pub fn set_host_config<T>(self, v: T) -> Selfwhere
T: Into<HostConfig>,
Sets the value of host_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::HostConfig;
let x = Instance::new().set_host_config(HostConfig::default()/* use setters */);Sourcepub fn set_or_clear_host_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<HostConfig>,
pub fn set_or_clear_host_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<HostConfig>,
Sets or clears the value of host_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::HostConfig;
let x = Instance::new().set_or_clear_host_config(Some(HostConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_host_config(None::<HostConfig>);Sourcepub fn set_workforce_identity_federation_config<T>(self, v: T) -> Selfwhere
T: Into<WorkforceIdentityFederationConfig>,
pub fn set_workforce_identity_federation_config<T>(self, v: T) -> Selfwhere
T: Into<WorkforceIdentityFederationConfig>,
Sets the value of workforce_identity_federation_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::WorkforceIdentityFederationConfig;
let x = Instance::new().set_workforce_identity_federation_config(WorkforceIdentityFederationConfig::default()/* use setters */);Sourcepub fn set_or_clear_workforce_identity_federation_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<WorkforceIdentityFederationConfig>,
pub fn set_or_clear_workforce_identity_federation_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<WorkforceIdentityFederationConfig>,
Sets or clears the value of workforce_identity_federation_config.
Example
use google_cloud_securesourcemanager_v1::model::instance::WorkforceIdentityFederationConfig;
let x = Instance::new().set_or_clear_workforce_identity_federation_config(Some(WorkforceIdentityFederationConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_workforce_identity_federation_config(None::<WorkforceIdentityFederationConfig>);Trait Implementations
impl StructuralPartialEq for Instance