#[non_exhaustive]pub struct Issue {
pub name: String,
pub title: String,
pub body: String,
pub state: State,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub close_time: Option<Timestamp>,
pub etag: String,
/* private fields */
}Expand description
Metadata of an Issue.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Unique identifier for an issue. The issue id is generated by
the server. Format:
projects/{project}/locations/{location}/repositories/{repository}/issues/{issue_id}
title: StringRequired. Issue title.
body: StringOptional. Issue body. Provides a detailed description of the issue.
state: StateOutput only. State of the issue.
create_time: Option<Timestamp>Output only. Creation timestamp.
update_time: Option<Timestamp>Output only. Last updated timestamp.
close_time: Option<Timestamp>Output only. Close timestamp (if closed). Cleared when is re-opened.
etag: StringOptional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
Implementations
Sourceimpl Issue
impl Issue
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Issue::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Issue::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_close_time<T>(self, v: T) -> Self
pub fn set_close_time<T>(self, v: T) -> Self
Sets the value of close_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_close_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_close_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_close_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of close_time.
Example
use wkt::Timestamp;
let x = Issue::new().set_or_clear_close_time(Some(Timestamp::default()/* use setters */));
let x = Issue::new().set_or_clear_close_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Issue