#[non_exhaustive]pub struct PullRequest {
pub name: String,
pub title: String,
pub body: String,
pub base: Option<Branch>,
pub head: Option<Branch>,
pub state: State,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub close_time: Option<Timestamp>,
/* private fields */
}Expand description
Metadata of a PullRequest. PullRequest is the request from a user to merge a branch (head) into another branch (base).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. A unique identifier for a PullRequest. The number
appended at the end is generated by the server. Format:
projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request_id}
title: StringRequired. The pull request title.
body: StringOptional. The pull request body. Provides a detailed description of the changes.
base: Option<Branch>Required. The branch to merge changes in.
head: Option<Branch>Immutable. The branch containing the changes to be merged.
state: StateOutput only. State of the pull request (open, closed or merged).
create_time: Option<Timestamp>Output only. Creation timestamp.
update_time: Option<Timestamp>Output only. Last updated timestamp.
close_time: Option<Timestamp>Output only. Close timestamp (if closed or merged). Cleared when pull request is re-opened.
Implementations
Sourceimpl PullRequest
impl PullRequest
Sourcepub fn set_or_clear_base<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_base<T>(self, v: Option<T>) -> Self
Sourcepub fn set_or_clear_head<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_head<T>(self, v: Option<T>) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PullRequest::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PullRequest::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_close_time<T>(self, v: T) -> Self
pub fn set_close_time<T>(self, v: T) -> Self
Sets the value of close_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_close_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_close_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_close_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of close_time.
Example
use wkt::Timestamp;
let x = PullRequest::new().set_or_clear_close_time(Some(Timestamp::default()/* use setters */));
let x = PullRequest::new().set_or_clear_close_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for PullRequest
impl Clone for PullRequest
Sourcefn clone(&self) -> PullRequest
fn clone(&self) -> PullRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PullRequest
impl Debug for PullRequest
Sourceimpl Default for PullRequest
impl Default for PullRequest
Sourcefn default() -> PullRequest
fn default() -> PullRequest
Sourceimpl Message for PullRequest
impl Message for PullRequest
Sourceimpl PartialEq for PullRequest
impl PartialEq for PullRequest
impl StructuralPartialEq for PullRequest