#[non_exhaustive]pub struct PullRequestComment {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub comment_detail: Option<CommentDetail>,
/* private fields */
}Expand description
PullRequestComment represents a comment on a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Unique identifier for the pull request comment. The comment id
is generated by the server. Format:
projects/{project}/locations/{location}/repositories/{repository}/pullRequests/{pull_request}/pullRequestComments/{comment_id}
create_time: Option<Timestamp>Output only. Creation timestamp.
update_time: Option<Timestamp>Output only. Last updated timestamp.
comment_detail: Option<CommentDetail>The comment detail. A comment can be a review, a general comment, or a code comment.
Implementations
Sourceimpl PullRequestComment
impl PullRequestComment
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = PullRequestComment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = PullRequestComment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PullRequestComment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PullRequestComment::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PullRequestComment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PullRequestComment::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_comment_detail<T: Into<Option<CommentDetail>>>(self, v: T) -> Self
pub fn set_comment_detail<T: Into<Option<CommentDetail>>>(self, v: T) -> Self
Sets the value of comment_detail.
Note that all the setters affecting comment_detail are mutually
exclusive.
Example
use google_cloud_securesourcemanager_v1::model::pull_request_comment::Review;
let x = PullRequestComment::new().set_comment_detail(Some(
google_cloud_securesourcemanager_v1::model::pull_request_comment::CommentDetail::Review(Review::default().into())));Sourcepub fn review(&self) -> Option<&Box<Review>>
pub fn review(&self) -> Option<&Box<Review>>
The value of comment_detail
if it holds a Review, None if the field is not set or
holds a different branch.
Sourcepub fn set_review<T: Into<Box<Review>>>(self, v: T) -> Self
pub fn set_review<T: Into<Box<Review>>>(self, v: T) -> Self
Sets the value of comment_detail
to hold a Review.
Note that all the setters affecting comment_detail are
mutually exclusive.
Example
use google_cloud_securesourcemanager_v1::model::pull_request_comment::Review;
let x = PullRequestComment::new().set_review(Review::default()/* use setters */);
assert!(x.review().is_some());
assert!(x.comment().is_none());
assert!(x.code().is_none());Sourcepub fn comment(&self) -> Option<&Box<Comment>>
pub fn comment(&self) -> Option<&Box<Comment>>
The value of comment_detail
if it holds a Comment, None if the field is not set or
holds a different branch.
Sourcepub fn set_comment<T: Into<Box<Comment>>>(self, v: T) -> Self
pub fn set_comment<T: Into<Box<Comment>>>(self, v: T) -> Self
Sets the value of comment_detail
to hold a Comment.
Note that all the setters affecting comment_detail are
mutually exclusive.
Example
use google_cloud_securesourcemanager_v1::model::pull_request_comment::Comment;
let x = PullRequestComment::new().set_comment(Comment::default()/* use setters */);
assert!(x.comment().is_some());
assert!(x.review().is_none());
assert!(x.code().is_none());Sourcepub fn code(&self) -> Option<&Box<Code>>
pub fn code(&self) -> Option<&Box<Code>>
The value of comment_detail
if it holds a Code, None if the field is not set or
holds a different branch.
Sourcepub fn set_code<T: Into<Box<Code>>>(self, v: T) -> Self
pub fn set_code<T: Into<Box<Code>>>(self, v: T) -> Self
Sets the value of comment_detail
to hold a Code.
Note that all the setters affecting comment_detail are
mutually exclusive.
Example
use google_cloud_securesourcemanager_v1::model::pull_request_comment::Code;
let x = PullRequestComment::new().set_code(Code::default()/* use setters */);
assert!(x.code().is_some());
assert!(x.review().is_none());
assert!(x.comment().is_none());Trait Implementations
Sourceimpl Clone for PullRequestComment
impl Clone for PullRequestComment
Sourcefn clone(&self) -> PullRequestComment
fn clone(&self) -> PullRequestComment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PullRequestComment
impl Debug for PullRequestComment
Sourceimpl Default for PullRequestComment
impl Default for PullRequestComment
Sourcefn default() -> PullRequestComment
fn default() -> PullRequestComment
Sourceimpl Message for PullRequestComment
impl Message for PullRequestComment
Sourceimpl PartialEq for PullRequestComment
impl PartialEq for PullRequestComment
impl StructuralPartialEq for PullRequestComment