#[non_exhaustive]pub struct Repository {
pub name: String,
pub description: String,
pub instance: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub etag: String,
pub uris: Option<URIs>,
pub initial_config: Option<InitialConfig>,
pub service_account: String,
pub scan_config: Option<ScanConfig>,
/* private fields */
}Expand description
Metadata of a Secure Source Manager repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. A unique identifier for a repository. The name should be of the
format:
projects/{project}/locations/{location_id}/repositories/{repository_id}
description: StringOptional. Description of the repository, which cannot exceed 500 characters.
instance: StringOptional. The name of the instance in which the repository is hosted,
formatted as
projects/{project_number}/locations/{location_id}/instances/{instance_id}
When creating repository via securesourcemanager.googleapis.com, this field
is used as input. When creating repository via *.sourcemanager.dev, this
field is output only.
uid: StringOutput only. Unique identifier of the repository.
create_time: Option<Timestamp>Output only. Create timestamp.
update_time: Option<Timestamp>Output only. Update timestamp.
etag: StringOptional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
uris: Option<URIs>Output only. URIs for the repository.
initial_config: Option<InitialConfig>Input only. Initial configurations for the repository.
service_account: StringOptional. Repository level service account (BYOSA).
scan_config: Option<ScanConfig>Optional. Provides configuration for scanning.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_instance<T: Into<String>>(self, v: T) -> Self
pub fn set_instance<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Repository::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Repository::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Repository::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_or_clear_uris<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_uris<T>(self, v: Option<T>) -> Self
Sourcepub fn set_initial_config<T>(self, v: T) -> Selfwhere
T: Into<InitialConfig>,
pub fn set_initial_config<T>(self, v: T) -> Selfwhere
T: Into<InitialConfig>,
Sets the value of initial_config.
Example
use google_cloud_securesourcemanager_v1::model::repository::InitialConfig;
let x = Repository::new().set_initial_config(InitialConfig::default()/* use setters */);Sourcepub fn set_or_clear_initial_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InitialConfig>,
pub fn set_or_clear_initial_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InitialConfig>,
Sets or clears the value of initial_config.
Example
use google_cloud_securesourcemanager_v1::model::repository::InitialConfig;
let x = Repository::new().set_or_clear_initial_config(Some(InitialConfig::default()/* use setters */));
let x = Repository::new().set_or_clear_initial_config(None::<InitialConfig>);Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = Repository::new().set_service_account("example");Sourcepub fn set_scan_config<T>(self, v: T) -> Selfwhere
T: Into<ScanConfig>,
pub fn set_scan_config<T>(self, v: T) -> Selfwhere
T: Into<ScanConfig>,
Sets the value of scan_config.
Example
use google_cloud_securesourcemanager_v1::model::repository::ScanConfig;
let x = Repository::new().set_scan_config(ScanConfig::default()/* use setters */);Sourcepub fn set_or_clear_scan_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ScanConfig>,
pub fn set_or_clear_scan_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<ScanConfig>,
Sets or clears the value of scan_config.
Example
use google_cloud_securesourcemanager_v1::model::repository::ScanConfig;
let x = Repository::new().set_or_clear_scan_config(Some(ScanConfig::default()/* use setters */));
let x = Repository::new().set_or_clear_scan_config(None::<ScanConfig>);Trait Implementations
Sourceimpl Clone for Repository
impl Clone for Repository
Sourcefn clone(&self) -> Repository
fn clone(&self) -> Repository
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Repository
impl Debug for Repository
Sourceimpl Default for Repository
impl Default for Repository
Sourcefn default() -> Repository
fn default() -> Repository
Sourceimpl PartialEq for Repository
impl PartialEq for Repository
impl StructuralPartialEq for Repository